
# q-expansion of newform 1575.4.a.i, downloaded from the LMFDB on 21 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K.gens()[0]**i for i in range(len(poly_data))]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1575
weight = 4
poly_data = [0, 1]

# The basis for the coefficient ring is just the power basis
# in the root of the defining polynomial above.
hecke_ring_character_values = None
aps_data = [[3], [0], [0], [-7], [-60], [-38], [-84], [110], [120], [-162], [236], [376], [126], [34], [-6], [582], [-492], [-880], [826], [666], [826], [-592], [792], [-1002], [-1442], [1182], [-56], [-1572], [-1402], [-846], [1096], [492], [-282], [2], [-606], [-2176], [-146], [826], [1206], [1398], [2424], [3728], [-2550], [1978], [-1170], [3584], [1640], [1888], [-2244], [-4084], [4026], [4590], [1946], [-3636], [4152], [5388], [-1194], [6788], [8908], [-6408], [3652], [-2214], [5452], [300], [3994], [2586], [6248], [-3062], [-5196], [8660], [-1128], [-6618], [-1568], [5200], [-1096], [-12318], [-6558], [1258], [2976], [-9070], [-6156], [-6874], [10218], [5830], [8588], [-12660], [-3636], [3022], [14742], [9268], [-13920], [8220], [-15752], [-6552], [4160], [5166], [12066], [17886], [-5168], [7850], [-2990], [-12486], [-732], [456], [-14092], [-10190], [23220], [14916], [16914], [5762], [28528], [12976], [8874], [-17170], [-26728], [24492], [1888], [-13134], [12882], [-7380], [560], [5722], [-13650], [1140], [32510], [-21402], [12170], [12012], [-8480], [10906], [-11104], [25416], [-30904], [16216], [-7230], [4790], [36114], [-13556], [39006], [-21480], [146], [-35562], [33964], [-23292], [33716], [35280], [-36902], [-30648], [20918], [19812], [-38900], [-16398], [-30422], [6222], [-21926], [-40662], [25688], [16026], [-18362], [-8034], [-30732], [28242], [-37496], [27204], [42954], [-10182], [30008], [47554], [60374], [-45114], [47820], [42536], [-11586], [30634], [27884], [-6246], [25292], [1434], [-27848], [-3724], [-2756], [66636], [1960], [-59028], [-6492], [-58830], [19816], [-4592], [-47554], [-38292], [-30890], [-25668], [-69784], [-54066], [-948], [13236], [55190], [25756], [-30744], [-1230], [-18942], [14384], [70990], [-36394], [-87012], [66498], [53516], [-20004], [-18684], [21782], [1114], [-47250], [39760], [-7872], [13368], [91622], [-76448], [54534], [6204], [29394], [46730], [-952], [46968], [-71156], [50724], [-83374], [-43872], [40026], [75112], [50568], [-68852], [-20914], [52904], [16068], [103588], [-4458], [84890], [48558], [58032], [11592], [20868], [62894], [24496], [-23974], [71100], [-5268], [7288], [43356], [-9664], [91404], [35692], [103542], [-49692], [-12490], [-68502], [-68736], [44318], [2716], [-60174], [96622], [-19676], [-110124], [-87640], [74734], [-18624], [68942], [27522], [-27018], [-99938], [9726], [-29752], [-13970], [-38486], [-95056], [138706], [-69464], [-64932], [67178], [-70810], [124764], [85362], [110432], [111510], [80660], [-138656], [-13242], [140686], [90126], [9812], [-48654], [94098], [5964], [-99294], [-164124], [-159572], [-102966], [-34612], [93762], [-95844], [-154676], [-78698], [139026], [3296], [-28404], [-64708], [-49754], [101652], [91784], [-142302], [-11792], [-25782], [58494], [30696], [50938], [52596], [-52666], [139500], [-95226], [-141338], [149868], [13070], [102634], [-189414], [110104], [-108282], [23114], [-120004], [-90488], [-91356], [117054], [-57274], [-72030], [-155824], [64104], [-95596], [53424], [87410], [-10212], [70238], [2320], [-14960], [56682], [-109710], [-29968], [-141882], [-119952], [68276], [-112826], [-120960], [24258], [-110950], [-69482], [10422], [-14528], [164522], [38016], [-68196], [127092], [-20526], [-4572], [101968], [127842], [45780], [-140412], [-18884], [141478], [-239958], [-181316], [61490], [-193740], [77150], [96924], [-171234], [-130732], [55204], [-253428], [29934], [-72434], [228246], [78118], [-180150], [61218], [82456], [-83730], [38810], [-107958], [28928], [193786], [-113798], [-128394], [-159550], [-222018], [152292], [56068], [137130], [87046], [-121624], [-152046], [-222424], [-217734], [-107980], [121962], [17332], [-60252], [211854], [-1960], [169540], [-38052], [-33572], [-96348], [13246], [117426], [237348], [127676], [-67214], [233034], [-285330], [107224], [-136440], [53238], [-169494], [-91406], [86616], [222876], [-31862], [-110622], [92316], [228132], [-133342], [147936]]
